@@ -8,7 +8,7 @@ exec_commands(c("wfcreate(wf=exec_commands,page=eviewsPage) m 2000 2022"))
 # The second example opens the `EViews` workfile and then generate a random series
 # named `y` and plots its line graph. It also freezes `ols` equation as `EviewsROLS`
 
-eviewsCommands=r'(pagecreate(page=eviewspage1) 7 2020 2022
+eviewsCommands='pagecreate(page=eviewspage1) 7 2020 2022
 for %page eviewspage eviewspage1
 pageselect {%page}
 genr y=@cumsum(nrnd)
@@ -17,8 +17,7 @@ equation ols.ls y c x
 graph x_graph.line x
 graph y_graph.area y
 freeze(OLSTable,mode=overwrite) ols
-next
-)'
+next'
 
 exec_commands(commands=eviewsCommands,wf="exec_commands")
 
